************************************************************************
* sanc_cc_v1.50 package.
************************************************************************
* File (main_cc_1loop_vegas.F).
************************************************************************
* This is the main FORTRAN module to calculate 1-loop EW and QCD
* radiative correction for the Charged Current Drell-Yan processes.
*
* It is produced by s2n package of SANC (v1.10) Project.
* Copyright (C), SANC Project Team, 2002-2012.
*
* http://sanc.jinr.ru/
* http://pcphsanc.cern.ch/
* E-mail: <sanc@jinr.ru>
************************************************************************
      program main_cc_1loop_vegas
      implicit none!
#include "s2n_declare.h"

      integer*4 lmu,imu,isetup,is,ic,ihard,pid,ptype
      integer*4 nrdm,nc1(10),it1(10),it2(10)
      real*8 sq,viso,brdq,ome
      real*8 born_sd,virt_sd,viso_sd,brdq_sd,hard_sd
      real*8 Oloop,Dloop,Oloop_sd,Dloop_sd
      real*8 Oloop_MS,Dloop_MS,Oloop_MS_sd,Dloop_MS_sd
      real*8 Mfscale
      common /s/ s,sq
      common /Mfscale/ Mfscale
      common /ihard/ ihard
      common /pid/ pid
      common /vegas_param/ nrdm,nc1,it1,it2
      common /ome/ ome

#include "init.h"

      if (isetup.eq.0) then
#include "sanc_input.h"
         print *, "SANC setup"
      elseif (isetup.eq.1) then
#include "leshw_input.h"
         print *, "Les Houches (2005) setup"
      elseif (isetup.eq.2) then
#include "tev4lhcw_input.h"
         print *, "TeV4LHC (2006) setup"
      elseif (isetup.eq.3) then
#include "leshw2007_input.h"
         print *, "Les Houches (2007) setup"
      endif

      mup = mup/10d0
      mdn = mdn/10d0
c      mbt = mbt/10d0

      call s2n_init()
      call ffini()

      call ProcessInit (pid)
      call PrintConsts (0)

      thmu = mw
      tlmu2 = 1d-1
      thmu2 = thmu**2
      print *, ''
      print *, "thmu(GeV)    = ", thmu
      print *, "thla2(GeV^2) = ", tlmu2

      born        = 0d0
      born_sd     = 0d0
      viso        = 0d0
      viso_sd     = 0d0
      virt        = 0d0
      virt_sd     = 0d0
      brdq        = 0d0
      brdq_sd     = 0d0
      hard        = 0d0
      hard_sd     = 0d0

      if ((pid.eq.1).or.(pid.eq.2).or.(pid.eq.3).or.
     &     (pid.eq.4).or.(pid.eq.5).or.(pid.eq.6).or.
     &     (pid.eq.25).or.(pid.eq.26).or.
     &     (pid.eq.27).or.(pid.eq.28).or.
     &     (pid.eq.29).or.(pid.eq.30).or.
     &     (pid.eq.31).or.(pid.eq.32))
     &     ptype = 1

      if ((pid.eq.19).or.(pid.eq.20).or.(pid.eq.21).or.
     &    (pid.eq.22).or.(pid.eq.23).or.(pid.eq.24)) ptype = 2

      if (ptype.eq.1) then

         s  = sq**2
         omega = ome*sq/2

         call BetaInit (pid)
         call Process_Reaction
     &        (born,born_sd,virt,virt_sd,viso,viso_sd,
     &        brdq,brdq_sd,hard,hard_sd)

      elseif (ptype.eq.2) then

         omega = ome

         call BetaInit (pid)
         call Process_Decay
     &        (born,born_sd,virt,virt_sd,viso,viso_sd,
     &        brdq,brdq_sd,hard,hard_sd)

      endif

      Oloop       = born+virt+viso+hard
      Oloop_sd    = sqrt(born_sd**2+virt_sd**2+viso_sd**2
     &     +hard_sd**2)
      Dloop       = (Oloop/born-1)
      Dloop_sd    = Oloop_sd/born
      Oloop_MS    = born+virt+viso-brdq+hard
      Oloop_MS_sd = sqrt(born_sd**2+virt_sd**2+viso_sd**2+brdq_sd**2
     &     +hard_sd**2)
      Dloop_MS    = (Oloop_MS/born-1)
      Dloop_MS_sd = Oloop_MS_sd/born

      print *
      call PrintProcess (pid)
      call PrintConsts (1)
      print *
      if (ptype.eq.1) print *, "sq(GeV)        = ", sq

      print *, "[Born]         = ", born, born_sd
      print *, "omega(GeV)     = ", omega
      print *, "[virt]         = ", virt,virt_sd
      print *, "[virtsoft]     = ", viso,viso_sd
      print *, "[virt_full]    = ", virt+viso,
     &     sqrt(virt_sd**2+viso_sd**2)
      print *, "[hard]         = ", hard,hard_sd
      print *, "[soha]         = ", viso+hard,viso_sd+hard_sd
      print *, "[1loop]        = ", Oloop,Oloop_sd
      print *, "[Delta](%)     = ", Dloop*100d0,Dloop_sd*100d0
      if ((ptype.eq.1).and.((iqed.eq.1).or.(iqcd.eq.1))) then
      print *, "[brdq]         = ", brdq,brdq_sd
      print *, "[1loop_MS]     = ", Oloop_MS,Oloop_MS_sd
      print *, "[Delta_MS](%)  = ", Dloop_MS*100d0,Dloop_MS_sd*100d0
      endif

      stop
      end
************************************************************************
      subroutine ProcessInit (pid)
      implicit none!
#include "s2n_declare.h"
      integer*4 pid
      real*8 Mfscale
      common /Mfscale/ Mfscale

      if ((pid.ne.1).and.(pid.ne.2).and.(pid.ne.3).and.(pid.ne.4).and.
     &     (pid.ne.5).and.(pid.ne.6).and.(pid.ne.19).and.
     &     (pid.ne.20).and.(pid.ne.21).and.(pid.ne.22).and.
     &     (pid.ne.23).and.(pid.ne.24).and.
     &     (pid.ne.25).and.(pid.ne.26).and.
     &     (pid.ne.27).and.(pid.ne.28).and.
     &     (pid.ne.29).and.(pid.ne.30).and.
     &     (pid.ne.31).and.(pid.ne.32))
     &     call PrintMessage (1,pid)

      print *
      call PrintProcess (pid)
      print *

      if     (pid.eq.1) then
         print *, "mup(GeV) =", mup
         print *, "mdn(GeV) =", mdn
         print *, "mel(GeV) =", mel
         Mfscale = mw
         mf  = mel
         mf1 = 0d0
      elseif (pid.eq.2) then
         print *, "mup(GeV) =", mup
         print *, "mdn(GeV) =", mdn
         print *, "mel(GeV) =", mel
         Mfscale = mw
         mf  = mel
         mf1 = 0d0
      elseif (pid.eq.3) then
         print *, "mup(GeV) =", mup
         print *, "mdn(GeV) =", mdn
         print *, "mmo(GeV) =", mmo
         Mfscale = mw
         mf  = mmo
         mf1 = 0d0
      elseif (pid.eq.4) then
         print *, "mup(GeV) =", mup
         print *, "mdn(GeV) =", mdn
         print *, "mmo(GeV) =", mmo
         Mfscale = mw
         mf  = mmo
         mf1 = 0d0
      elseif (pid.eq.5) then
         print *, "mup(GeV) =", mup
         print *, "mdn(GeV) =", mdn
         print *, "mta(GeV) =", mta
         Mfscale = mw
         mf  = mta
         mf1 = 0d0
      elseif (pid.eq.6) then
         print *, "mup(GeV) =", mup
         print *, "mdn(GeV) =", mdn
         print *, "mta(GeV) =", mta
         Mfscale = mw
         mf  = mta
         mf1 = 0d0
      elseif (pid.eq.19) then
         print *, "mtp(GeV) =", mtp
         print *, "mbt(GeV) =", mbt
         print *, "mel(GeV) =", mel
         Mfscale = mw
         mf  = mel
         mf1 = 0d0
      elseif (pid.eq.20) then
         print *, "mtp(GeV) =", mtp
         print *, "mbt(GeV) =", mbt
         print *, "mel(GeV) =", mel
         Mfscale = mw
         mf  = mel
         mf1 = 0d0
      elseif (pid.eq.21) then
         print *, "mtp(GeV) =", mtp
         print *, "mbt(GeV) =", mbt
         print *, "mmo(GeV) =", mmo
         Mfscale = mw
         mf  = mmo
         mf1 = 0d0
      elseif (pid.eq.22) then
         print *, "mtp(GeV) =", mtp
         print *, "mbt(GeV) =", mbt
         print *, "mmo(GeV) =", mmo
         Mfscale = mw
         mf  = mmo
         mf1 = 0d0
      elseif (pid.eq.23) then
         print *, "mtp(GeV) =", mtp
         print *, "mbt(GeV) =", mbt
         print *, "mup(GeV) =", mup
         print *, "mdn(GeV) =", mdn
         Mfscale = mw
         mf  = mup
         mf1 = mdn
      elseif (pid.eq.24) then
         print *, "mtp(GeV) =", mtp
         print *, "mbt(GeV) =", mbt
         print *, "mup(GeV) =", mup
         print *, "mdn(GeV) =", mdn
         Mfscale = mw
         mf  = mup
         mf1 = mdn
      elseif (pid.eq.25) then
         print *, "mup(GeV) =", mup
         print *, "mdn(GeV) =", mdn
         print *, "mbt(GeV) =", mbt
         print *, "mtp(GeV) =", mtp
         Mfscale = mw
         mf  = mtp
         mf1 = mbt
      elseif (pid.eq.26) then
         print *, "mup(GeV) =", mup
         print *, "mdn(GeV) =", mdn
         print *, "mbt(GeV) =", mbt
         print *, "mtp(GeV) =", mtp
         Mfscale = mw
         mf  = mtp
         mf1 = mbt
      elseif (pid.eq.27) then
         print *, "mtp(GeV) =", mtp
         print *, "mbt(GeV) =", mbt
         print *, "mup(GeV) =", mup
         print *, "mdn(GeV) =", mdn
         Mfscale = mw
         mf  = mtp
         mf1 = mdn
      elseif (pid.eq.28) then
         print *, "mtp(GeV) =", mtp
         print *, "mbt(GeV) =", mbt
         print *, "mup(GeV) =", mup
         print *, "mdn(GeV) =", mdn
         Mfscale = mw
         mf  = mtp
         mf1 = mdn
      elseif (pid.eq.29) then
         print *, "mtp(GeV) =", mtp
         print *, "mbt(GeV) =", mbt
         print *, "mup(GeV) =", mup
         print *, "mdn(GeV) =", mdn
         Mfscale = mw
         mf  = mtp
         mf1 = mup
      elseif (pid.eq.30) then
         print *, "mtp(GeV) =", mtp
         print *, "mbt(GeV) =", mbt
         print *, "mup(GeV) =", mup
         print *, "mdn(GeV) =", mdn
         Mfscale = mw
         mf  = mtp
         mf1 = mup
      elseif (pid.eq.31) then
         print *, "mup(GeV) =", mup
         print *, "mdn(GeV) =", mdn
         print *, "mw(GeV)  =", mw
         print *, "mh(GeV)  =", mh
         Mfscale = mw
         mf  = mw
         mf1 = mh
      elseif (pid.eq.32) then
         print *, "mup(GeV) =", mup
         print *, "mdn(GeV) =", mdn
         print *, "mw(GeV)  =", mw
         print *, "mh(GeV)  =", mh
         Mfscale = mw
         mf  = mw
         mf1 = mh
      else
         call PrintMessage (1,pid)
         stop
      endif

      return
      end
************************************************************************
      subroutine BetaInit (pid)
      implicit none!
#include "s2n_declare.h"
      integer*4 pid
      real*8 sq,sqrtlstpbt,sqrtlswh
      common /s/ s,sq

      sq = sqrt(s)

      if     ((pid.eq.1).or.(pid.eq.2)) then
         if (sq.le.mf) call PrintMessage (2,pid)
         betaf = 1d0
      elseif ((pid.eq.3).or.(pid.eq.4).or.(pid.eq.5).or.(pid.eq.6)) then
         if (sq.le.mf) call PrintMessage (2,pid)
         betaf = (s-mf**2)/(s+mf**2)
      elseif ((pid.eq.25).or.(pid.eq.26)) then
         sqrtlstpbt = dsqrt((s-mtp**2-mbt**2)**2-4d0*mtp**2*mbt**2)
         betaf = sqrtlstpbt/(s+mbt**2-mtp**2)
      elseif ((pid.eq.31).or.(pid.eq.32)) then
         sqrtlswh = dsqrt((s-mw**2-mh**2)**2-4d0*mw**2*mh**2)
         betaf = sqrtlswh/(s+mh**2-mw**2)
      endif

      return
      end
************************************************************************
      subroutine PrintMessage (pmg,pid)
      implicit none!
#include "s2n_declare.h"
      integer*4 pmg,pid
      real*8 sq0,sq
      common /s/ s,sq

      sq0 = mf

      if (pmg.eq.1)
     &     print *, "Fatal error, invalid process number: pid = ", pid
      if (pmg.eq.2)
     &     print *, "Fatal error, process under threshold: sq = ",
     &     sqrt(s),"  <  (Mf1+Mf2) = ", sq0 

      stop
      end
************************************************************************
      subroutine PrintConsts (pmg)
      implicit none!
      integer pmg
#include "s2n_declare.h"

      if ((pmg.eq.0).or.(pmg.eq.1)) then
         print *
         print *, "flag iqed     = ",iqed
         print *, "flag iew      = ",iew
         print *, "flag qcd      = ",iqcd
         print *, "flag gfscheme = ",gfscheme
         print *, "flag ilin     = ",ilin
      endif
      if ((pmg.eq.0).or.(pmg.eq.2)) then
         print *
         print *, "alphai    = ",alphai
         print *, "alpha     = ",alpha
         print *, "GF(GeV-^2)= ",gf
         print *, "g         = ",g
         print *, "e         = ",e
         print *, "alphas    = ",alphas
         print *, "gs        = ",gs
         print *, "cwm       = ",ctw
         print *, "swm2      = ",stw2
         print *, "mh(GeV)   = ",mh
         print *, "mw(GeV)   = ",mw
         print *, "mz(GeV)   = ",mz
         print *, "wz(GeV)   = ",wz
         print *, "ww(GeV)   = ",ww
         print *, "wh(GeV)   = ",wh
         print *, "wtp(GeV)  = ",wtp
      endif

      return
      end
************************************************************************
      subroutine PrintProcess (pid)
      implicit none!
      integer*4 pid

      if (pid.eq.1) print *,
     &  "pid = ", pid, ": proccess anti-up + dn -> en   + el^-"
      if (pid.eq.2) print *,
     &  "pid = ", pid, ": proccess anti-dn + up -> el^+ + en"
      if (pid.eq.3) print *,
     &  "pid = ", pid, ": proccess anti-up + dn -> mn   + mo^-"
      if (pid.eq.4) print *,
     &  "pid = ", pid, ": proccess anti-dn + up -> mo^+ + mn"
      if (pid.eq.5) print *,
     &  "pid = ", pid, ": proccess anti-up + dn -> tn   + ta^-"
      if (pid.eq.6) print *,
     &  "pid = ", pid, ": proccess anti-dn + up -> ta^+ + tn"
      if (pid.eq.19) print *,
     &  "pid = ", pid, ": proccess anti-tp -> anti-bt + en      + el^-"
      if (pid.eq.20) print *,
     &  "pid = ", pid, ": proccess      tp ->      bt + el^+    + en"
      if (pid.eq.21) print *,
     &  "pid = ", pid, ": proccess anti-tp -> anti-bt + mn      + mo^-"
      if (pid.eq.22) print *,
     &  "pid = ", pid, ": proccess      tp ->      bt + mo^+    + mn"
      if (pid.eq.23) print *,
     &  "pid = ", pid, ": proccess anti-tp -> anti-bt + anti-up + dn"
      if (pid.eq.24) print *,
     &  "pid = ", pid, ": proccess      tp ->      bt + anti-dn + up"
      if (pid.eq.25) print *,
     &  "pid = ", pid, ": proccess anti-up + dn -> anti-tp + bt"
      if (pid.eq.26) print *,
     &  "pid = ", pid, ": proccess anti-dn + up -> anti-bt + tp"
      if (pid.eq.27) print *,
     &  "pid = ", pid,
     &  ": proccess      bt +      up ->      dn +      tp"
      if (pid.eq.28) print *,
     &  "pid = ", pid,
     &  ": proccess anti-up + anti-bt -> anti-tp + anti-dn"
      if (pid.eq.29) print *,
     &  "pid = ", pid,
     &  ": proccess anti-dn +      bt -> anti-up +      tp"
      if (pid.eq.30) print *,
     &  "pid = ", pid,
     &  ": proccess anti-bt +      dn -> anti-tp +      up"
      if (pid.eq.31) print *,
     &  "pid = ", pid, ": proccess anti-up + dn -> W^- + H  "
      if (pid.eq.32) print *,
     &  "pid = ", pid, ": proccess anti-dn + up -> H   + W^+"

      return
      end
************************************************************************
