************************************************************************
* sanc_cc_v1.40 package.
************************************************************************
* File (cc_br_2122_1314.f) is created on Tue Aug  9 22:43:03 MSD 2011.
************************************************************************
* This is the FORTRAN module (cc_bo_2122_1314) to calculate EW
* integrated Born width for the anti-tp -> anti-bt + anti-up + dn decay.
*
* It is produced by s2n package of SANC (v1.10) Project.
* Copyright (C), SANC Project Team, 2002-2011.
*
* http://sanc.jinr.ru/
* http://pcphsanc.cern.ch/
* E-mail: <sanc@jinr.ru>
************************************************************************
      subroutine cc_bo_2122_1314 (s,born)
      implicit none!
      include 's2n_declare.h'

      real*8 sqrtlstpbt
      complex*16 propws,propiws,propwsc

      cmw2 = mw2

      if (irun.eq.0) then
         propiws = (cmw2-s)
      elseif (irun.eq.1) then
         propiws = (dcmplx(mw**2,-s*ww/mw)-s)
      endif
      propws = 1d0/propiws
      propwsc = dconjg(propws)

      sqrtlstpbt = dsqrt((s-mtp**2-mbt**2)**2-4d0*mtp**2*mbt**2)

      born=
     & +sqrtlstpbt*propws*propwsc/pi**3*gf**2*mw**4*(-1d0/16/mtp**3*s**2
     & +1d0/32/mtp**3*mbt**2*s+1d0/32/mtp**3*mbt**4+1d0/32/mtp*s-1d0/16/
     & mtp*mbt**2+1d0/32*mtp)

      return
      end
************************************************************************
* This is the FORTRAN module (cc_br_2122_1314) to calculate EW Born
* width and soft photon Bremsstrahlung
* for the anti-tp -> anti-bt + anti-up + dn decay.
*
* It is produced by s2n package of SANC (v1.10) Project.
* Copyright (C), SANC Project Team, 2002-2011.
*
* http://sanc.jinr.ru/
* http://pcphsanc.cern.ch/
* E-mail: <sanc@jinr.ru>
************************************************************************
      subroutine cc_br_2122_1314 (qs,ts,us,born,soft,hard)
      implicit none!
      include 's2n_declare.h'

      real*8 qw,softvirtisr,softvirtfsr,softvirtifi
      real*8 sqrtlstpbt,isqrtlstpbt
      real*8 betatpsbt,ibetatpsbt,betatpjsbt,ibetatpjsbt
      real*8 betatpbts,ibetatpbts,umin,umax
      real*8 jbwtpbtsq,jbwbttpsq
      real*8 a0fup,a0fdn,a0ftp,a0fbt
      real*8 b0ptpctp
      complex*16 propws,propiws,propwsc
      real*8 c0wtpupts,c0wtpdnus,c0wtpbtqs

      cmw2 = mw2
      qw   = 1d0

      s = -qs
      t = -ts
      u = -us

      sqrtlstpbt = dsqrt((s-mtp**2-mbt**2)**2-4d0*mtp**2*mbt**2)
      isqrtlstpbt = 1d0/sqrtlstpbt

      cosf = (u-t)/sqrtlstpbt
      sinf = dsqrt(1d0-cosf**2)

      if (irun.eq.0) then
         propiws = (cmw2-s)
      elseif (irun.eq.1) then
         propiws = (dcmplx(mw**2,-s*ww/mw)-s)
      endif
      propws = 1d0/propiws
      propwsc = dconjg(propws)

      born=
     & +propws*propwsc/pi**3*gf**2*mw**4*(-3d0/16/mtp**3*u**2+3d0/16/mtp
     & **3*mbt**2*u+3d0/16/mtp*u-3d0/16/mtp*mbt**2)

      born = born*sqrtlstpbt/2d0
      virt = 0d0
      soft = 0d0
      hard = 0d0

      if (iborn.eq.1) return

      betatpjsbt = sqrtlstpbt/(rtpm2-s-rbtm2)
      ibetatpjsbt = 1d0/betatpjsbt

      betatpsbt = sqrtlstpbt/(rtpm2+s-rbtm2)
      ibetatpsbt = 1d0/betatpsbt

      betatpbts = sqrtlstpbt/(rtpm2+rbtm2-s)
      ibetatpbts = 1d0/betatpbts

      jbwbttpsq = log((rtpm2-rbtm2+s-sqrtlstpbt)/(rtpm2-rbtm2+s+sqrtlstpbt))
      jbwtpbtsq = log((rtpm2-rbtm2-s+sqrtlstpbt)/(rtpm2-rbtm2-s-sqrtlstpbt))

      umin = (rtpm2+rbtm2-s-sqrtlstpbt)/2d0
      umax = (rtpm2+rbtm2-s+sqrtlstpbt)/2d0

      a0fup = log(rupm2/thmu2) - 1d0
      a0fdn = log(rdnm2/thmu2) - 1d0
      a0ftp = log(rtpm2/thmu2) - 1d0
      a0fbt = log(rbtm2/thmu2) - 1d0

      b0ptpctp  = 1d0/mtp**2*log(wtp/mtp)
      c0wtpupts = c0analys(mtp,mup,wtp,ts)
      c0wtpdnus = c0analys(mtp,mdn,wtp,us)
      c0wtpbtqs = c0analys(mtp,mbt,wtp,qs)

      softvirtisr=
     & +born/pi*alpha*qtp**2*(1-b0ptpctp*mtp**2)
     & +ibetatpjsbt*born/pi*alpha*qbt**2*(1d0/2*jbwtpbtsq)
     & +a0ftp*born/pi*alpha*qtp**2*(-3d0/4)
     & +a0fbt*born/pi*alpha*qbt**2*(-3d0/4)
     & +c0wtpbtqs*born/pi*alpha*qtp*qbt*(s-mbt**2-mtp**2)
     & +log(4*omega**2/mbt**2)*born/pi*alpha*qbt**2*(-1d0/2)

      softvirtfsr=
     & +a0fup*born/pi*alpha*qup**2*(-3d0/4)
     & +a0fdn*born/pi*alpha*qdn**2*(-3d0/4)
     & +log(4*omega**2/s)*born/pi*alpha*qdn**2*(-1d0/2)
     & +log(4*omega**2/s)*born/pi*alpha*qup**2*(-1d0/2)
     & +log(4*omega**2/s)*log(mdn**2/s)*born/pi*alpha*qup*qdn*(-1d0/2)
     & +log(4*omega**2/s)*log(mup**2/s)*born/pi*alpha*qup*qdn*(-1d0/2)

      softvirtifi=
     & +born/pi*alpha*qdn*qbt*(-1d0/4*jbwtpbtsq**2)
     & +born/pi*alpha*qup*qbt*(1d0/4*jbwtpbtsq**2)
     & +c0wtpdnus*born/pi*alpha*qdn*qtp*(-u+mtp**2)
     & +c0wtpupts*born/pi*alpha*qup*qtp*(t-mtp**2)
     & +log(-1+1d0/mbt**2*u)**2*born/pi*alpha*qup*qbt*(1)
     & +log(-1+1d0/mbt**2*t)**2*born/pi*alpha*qdn*qbt*(-1)
     & +log(1d0/mbt**2*u)**2*born/pi*alpha*qup*qbt*(-1d0/2)
     & +log(1d0/mbt**2*t)**2*born/pi*alpha*qdn*qbt*(1d0/2)
     & +log(mbt**2/s)*log(-1+1d0/mbt**2*u)*born/pi*alpha*qup*qbt*(1)
     & +log(mbt**2/s)*log(-1+1d0/mbt**2*t)*born/pi*alpha*qdn*qbt*(-1)
     & +log(mbt**2/s)**2*born/pi*alpha*qdn*qbt*(-1d0/4)
     & +log(mbt**2/s)**2*born/pi*alpha*qup*qbt*(1d0/4)
     & +log(4*omega**2/s)*log(-1+1d0/mbt**2*u)*born/pi*alpha*qup*qbt*(-1
     & )
     & +log(4*omega**2/s)*log(-1+1d0/mbt**2*t)*born/pi*alpha*qdn*qbt*(1)
     & +log(4*omega**2/s)*log(mbt**2/s)*born/pi*alpha*qdn*qbt*(1d0/2)
     & +log(4*omega**2/s)*log(mbt**2/s)*born/pi*alpha*qup*qbt*(-1d0/2)
     & +log(4*omega**2/s)*log(mdn**2/s)*born/pi*alpha*qdn*qbt*(-1d0/2)
     & +log(4*omega**2/s)*log(mup**2/s)*born/pi*alpha*qup*qbt*(1d0/2)
     & +ddilog(mbt**2/t)*born/pi*alpha*qdn*qbt*(1)
     & +ddilog(mbt**2/u)*born/pi*alpha*qup*qbt*(-1)
     & +ddilog(1/(u-mbt**2)*u-1/(u-mbt**2)*umin)*born/pi*alpha*qup*qbt*(
     & 1)
     & +ddilog(1/(u-mbt**2)*u-1/(u-mbt**2)*umax)*born/pi*alpha*qup*qbt*(
     & 1)
     & +ddilog(1/(t-mbt**2)*t-1/(t-mbt**2)*umin)*born/pi*alpha*qdn*qbt*(
     & -1)
     & +ddilog(1/(t-mbt**2)*t-1/(t-mbt**2)*umax)*born/pi*alpha*qdn*qbt*(
     & -1)
     & +ddilog(1d0)*born/pi*alpha*qdn*qbt*(3)
     & +ddilog(1d0)*born/pi*alpha*qup*qbt*(-3)

      if (iqed.eq.1) then
         soft = softvirtisr+softvirtfsr+softvirtifi
      elseif(iqed.eq.2) then
         soft = softvirtisr
      elseif(iqed.eq.3) then
         soft = softvirtifi
      elseif(iqed.eq.4) then
         soft = softvirtfsr
      endif

      soft = soft*cfprime

      return
      end
